<div align="center">
  <img src="http://arelle.org/arelle/wp-content/themes/platform/images/logo-platform.png">
</div>



[Arelle](https://arelle.org/arelle/) is an end-to-end open source XBRL platform,
which provides the XBRL community with an easy to use set of tools.  It supports
XBRL and its extension features in an extensible manner.  It does this in a
compact yet robust framework that can be used as a desktop application and can
be integrated with other applications and languages utilizing its web service.

## Features
* Support for XBRL versioning. Validation tool for versioning reports and a
  production tool to generate the basics of a versioning report that can be
  inferred by diffing two DTSs.
* Edgar and Global Filer Manual validation
* Base Specification, Dimensions, Generic linkbase validation
* Formula validation including support for extension modules
* Instance creation is supported using forms defined by the table linkbase (Eurofiling version).
* RSS Watch facility
* Users can explore the functionality and features from an interactive GUI,
  command line interface, or web services, and can develop their own controller
  interfaces as needed.
* The Web Service API allows XBRL integration with applications, such as those in
  Excel, Java or Oracle.
* QuickBooks is supported by XBRL-GL.


## Installation

Please check out our [Arelle install guide](INSTALLATION.md).


## Contribution guidelines

If you want to contribute to Arelle, be sure to review the
[contribution guidelines](CONTRIBUTING.md).

We use [GitHub issues](https://github.com/arelle/arelle/issues) for
tracking requests and bugs.


## License

[Apache License 2.0](LICENSE.md)
